# flask-app-creator

Script para criar a base de um projeto flask para usar como extensão ou como aplicação final

## Instalação

Instale usando o pipx (recomendado):

`pipx install flask-app-creator`

Mas você pode também instalar com pip:

`pip install flask-app-creator`

## Como Usar

Crie a pasta para seu projeto e dentro dela rode `flask-app-creator .`

Rode com `flask-app-creator . --extension` para criar uma extensão.
